==> haskell-uri-bytestring-0.3.2.1-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-uri-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uri-bytestring
version: 0.3.2.1
id: uri-bytestring-0.3.2.1-JCtt9azTlkZIBDjRTG5dLJ
key: uri-bytestring-0.3.2.1-JCtt9azTlkZIBDjRTG5dLJ
license: BSD-3-Clause
copyright: Soostone Inc.
maintainer: Michael Xavier <michael.xavier@soostone.com>
author: Doug Beardsley, Michael Xavier
homepage: https://github.com/Soostone/uri-bytestring
synopsis: Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.
category: Web
abi: d6f9b3b061320ac58247f063acaf1300
exposed: True
exposed-modules:
    URI.ByteString URI.ByteString.QQ
hidden-modules: URI.ByteString.Lens URI.ByteString.Types
                URI.ByteString.Internal
import-dirs: /usr/lib/ghc-8.6.4/site-local/uri-bytestring-0.3.2.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/uri-bytestring-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/uri-bytestring-0.3.2.1
hs-libraries: HSuri-bytestring-0.3.2.1-JCtt9azTlkZIBDjRTG5dLJ
depends:
    attoparsec-0.13.2.2-4iFLH0ONEYhG16eDwwtqQO base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    containers-0.6.0.1 template-haskell-2.14.0.0
    th-lift-instances-0.1.11-I2UhE4Dqb4HG3Lp04x0iVm
haddock-interfaces: /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock
haddock-html: /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-bytestring-0.3.2.1-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-uri-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uri-bytestring
version: 0.3.2.1
id: uri-bytestring-0.3.2.1-9YKW1mJtUvQA4ZgV12aH8a
key: uri-bytestring-0.3.2.1-9YKW1mJtUvQA4ZgV12aH8a
license: BSD-3-Clause
copyright: Soostone Inc.
maintainer: Michael Xavier <michael.xavier@soostone.com>
author: Doug Beardsley, Michael Xavier
homepage: https://github.com/Soostone/uri-bytestring
synopsis: Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.
category: Web
abi: 9bd598c31c417761a76e8a9491355100
exposed: True
exposed-modules:
    URI.ByteString URI.ByteString.QQ
hidden-modules: URI.ByteString.Lens URI.ByteString.Types
                URI.ByteString.Internal
import-dirs: /usr/lib/ghc-8.6.4/site-local/uri-bytestring-0.3.2.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/uri-bytestring-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/uri-bytestring-0.3.2.1
hs-libraries: HSuri-bytestring-0.3.2.1-9YKW1mJtUvQA4ZgV12aH8a
depends:
    attoparsec-0.13.2.2-3nUJVHBWBICGFmP4JcM3ay base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    containers-0.6.0.1 template-haskell-2.14.0.0
    th-lift-instances-0.1.11-I2UhE4Dqb4HG3Lp04x0iVm
haddock-interfaces: /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock
haddock-html: /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
